@@ -1,28 +1,25 @@
-# ABSTRACT: Rapid creation of REST web services with sessions and persistent data
+# ABSTRACT: Rapid creation of RESTful Web Services with sessions and persistent data
 # Provides Routes for authentication, persistent session data
 # It can handle the formats : JSON , XML , YAML, PERL , HUMAN
 #
 # Quick diffences between plugin and Dancer2 core
 #
-#   main                               plugin                        
-#   -------------------------------------------------------------
-#   Dancer2 method                     $plugin->app->DancerMethod    
-#   setting('Key') or config->{Key}    $plugin->config->{key} ,  $plugin->app->{name},  $plugin->{app}->{name},
+#   main                             plugin                        
+#   -----------------------------------------------------------
+#   DancerMethod                     $plugin->app->DancerMethod    
+#   setting('Key') or config->{Key}  $plugin->config->{key} ,  $plugin->app->{name}
 #
-#   change setting :  $plugin->{app}->{config}->{SomeSetting} = 'foo';
+#   change setting: $plugin->{app}->{config}->{SomeSetting} = 'foo';
 #
 #
-# George Mpouras
-# george.mpouras@yandex.com
+# George Mpouras , george.mpouras@yandex.com
 # 25 Sep 2016 , Athens - Greece
 
 
-
-
 package Dancer2::Plugin::WebService;
 use	Dancer2::Plugin;
 use	Storable;
-our	$VERSION = '3.010';
+our	$VERSION = '3.012';
 
 if ($^O =~ /(?i)MSWin/) {warn "Sorry windows operating system is not supported\n"; exit 1}
 
@@ -47,9 +44,9 @@ has ClientIP             => (is=>'rw', default=> '');
 has route_name           => (is=>'rw', default=> '');
 has error                => (is=>'rw', default=> 0);
 has errormessage         => (is=>'rw', default=> 'ok');
-has data_user            => (is=>'rw', default=> sub{ {} });	# hash holding the data user send to us at "data_from"
 has data_from            => (is=>'rw', default=> '');		# string of user data
 has data_to              => (is=>'rw', default=> '');		# string of user data rebuilded
+has data_user            => (is=>'rw', default=> sub{ {} });	# hash   of user data, send to us at "data_from"
 has Authentication_method=> (is=>'rw', default=> '');
 has auth_member_of       => (is=>'rw', default=> sub{ [] });
 has auth_result          => (is=>'rw', default=> 0);
@@ -98,8 +95,8 @@ __MKDIR($plugin->dir_session) or die 'Could not create the session directory '.$
 unless (-d $module_dir) {warn "Sorry could not define the Dancer2::Plugin::WebService installation directory\n"; exit 1}
 print STDOUT "Application name     : $plugin->{app}->{config}->{appname}\n";
 print STDOUT "Application version  : $plugin->{app}->{config}->{plugins}->{WebService}->{Version}\n";
-print STDOUT "Run as user          : ". (getpwuid($>))[0] ."\n";
-print STDOUT "Started at           : ". scalar(localtime $^T) ."\n";
+print STDOUT 'Run as user          : '. (getpwuid($>))[0] ."\n";
+print STDOUT 'Started at           : '. scalar(localtime $^T) ."\n";
 print STDOUT "Process identifier   : $$\n";
 print STDOUT "WebService version   : $VERSION\n";
 print STDOUT "Module dir           : $module_dir\n";
@@ -107,8 +104,8 @@ print STDOUT "Module dir           : $module_dir\n";
 	foreach (keys %{$plugin->config->{'Authentication method'}} ) {
 	next unless $plugin->config->{'Authentication method'}->{$_}->{Active} =~/(?i)yes/;
 	$plugin->config->{'Authentication method'}->{$_}->{Command} =~s/^MODULE_INSTALL_DIR/$module_dir/;
-	if ( ! -f $plugin->config->{'Authentication method'}->{$_}->{Command} )	{ warn 'Sorry, could not found the external authorization utility : "'. $plugin->config->{'Authentication method'}->{$_}->{Command} ."\"\n"; exit 1 }
-	if ( ! -x $plugin->config->{'Authentication method'}->{$_}->{Command} )	{ warn 'Sorry, the external authorization utility "'. $plugin->config->{'Authentication method'}->{$_}->{Command} .'" is not executable from user '.getpwuid($>) ."\n"; exit 1 }
+	unless (-f $plugin->config->{'Authentication method'}->{$_}->{Command})	{ warn 'Sorry, could not found the external authorization utility : "'. $plugin->config->{'Authentication method'}->{$_}->{Command} ."\"\n"; exit 1 }
+	unless (-x $plugin->config->{'Authentication method'}->{$_}->{Command})	{ warn 'Sorry, the external authorization utility "'. $plugin->config->{'Authentication method'}->{$_}->{Command} .'" is not executable from user '.getpwuid($>) ."\n"; exit 1 }
 	$plugin->Authentication_method($_);	
 	print STDOUT "Authorization method : $_\n";
 	print STDOUT 'Authorization command: ', $plugin->config->{'Authentication method'}->{$_}->{Command} ,"\n";
@@ -130,9 +127,9 @@ opendir __SESSIONDIR, $_ or die "Could not list session directory $_ because $!\
 	if (-f "$_/$session") {unlink "$_/$session"; next}
 
 		if ((-f "$_/$session/__clientip") && (-f "$_/$session/__lastaccess") && (-f "$_/$session/__logintime") && (-f "$_/$session/__user")) {
-		my $lastaccess = ${  Storable::retrieve  "$_/$session/__lastaccess"  };
+		my $lastaccess = ${  Storable::retrieve  "$_/$session/__lastaccess" };
 
-			if ( time - $lastaccess > $plugin->config->{'Session idle timout'} ) {
+			if (time - $lastaccess > $plugin->config->{'Session idle timout'}) {
 			print STDOUT "Delete expired session: $session\n";
 			system $plugin->rm, '--recursive', '--force', "$_/$session"
 			}
@@ -156,13 +153,11 @@ closedir __SESSIONDIR;
 	$plugin->app->add_hook( Dancer2::Core::Hook->new(name => 'after', code => sub { $plugin->data_user({}) }) );
 
 	# <before hook>
-	$plugin->app->add_hook( Dancer2::Core::Hook->new(name => 'before', code => sub
-	{
+	$plugin->app->add_hook( Dancer2::Core::Hook->new(name => 'before',code => sub {
 	$_ = (values %{ $plugin->app->request->params('route') })[0] // '';
 	$plugin->app->request->path =~/^\/*(.+?)\/*$_$/;
 	$plugin->route_name($^N);
 
-
 	$plugin->config->{Routes}->{ $plugin->route_name } = 'public' unless exists $plugin->config->{Routes}->{ $plugin->route_name }; # If a route is not defined at the configuration file we will considered it as public
 	$plugin->from($plugin->app->request->query_parameters->{from} // $plugin->config->{'Default format'});
 	$plugin->to(  $plugin->app->request->query_parameters->{to}   // $plugin->from);
@@ -214,11 +209,9 @@ closedir __SESSIONDIR;
 
 
 
-
 	# Built in route /info
 	$plugin->app->add_route( regexp=> '/info', method=> 'get', code=> sub { $_[0]->forward('/info/version') } );
 
-
 	# Built in route /info/:what
 	$plugin->app->add_route(
 	method => 'get',
@@ -255,7 +248,7 @@ closedir __SESSIONDIR;
 		'Header accept'		=> $plugin->app->request->header('accept'),
 		'Parameters url'	=> join(' ', $plugin->app->request->params('query')),
 		'Parameters route'	=> join(' ', $plugin->app->request->params('route')),
-		'Parameters body'	=> join(' ', $plugin->app->request->params('body')) )
+		'Parameters body'	=> join(' ', $plugin->app->request->params('body')))
 		}
 		else {
 		$plugin->RestReply(error=>5, errormessage=>'Not existing internal route \''.$app->request->param('what').'\' Please choose one of : version, about, client')
@@ -711,7 +704,7 @@ my @keys;
 		$plugin->data_user->{$_[$i]} = $_[$j]
 		}
 
-	%{ $plugin->data_user }{ @keys }
+	map {$_, $plugin->data_user->{$_}} @keys
 	}
 }
 
@@ -805,8 +798,8 @@ my %hash;
 #   Session data are not volatile like the user data.
 #   They are persistent between requests
 #
-#   set_data_session(   new1 => 'foo1', new2 => 'foo2'   ); 
-#   set_data_session( { new1 => 'foo1', new2 => 'foo2' } );
+#   set_data_session(  new1 => 'foo1', new2 => 'foo2'  ); 
+#   set_data_session( {new1 => 'foo1', new2 => 'foo2'} );
 #
 sub set_data_session
 {
@@ -884,23 +877,23 @@ __END__
 
 =head1 NAME
 
-Dancer2::Plugin::WebService - Rapid creation of REST web services with sessions and persistent data
+Dancer2::Plugin::WebService - Rapid creation of RESTful Web Services with sessions and persistent data
 
 =head1 VERSION
 
-version 3.010
+version 3.012
 
 =head2 NAME
 
-Dancer2::Plugin::WebService Rapid creation of REST web services with sessions and persistent data
+Dancer2::Plugin::WebService Rapid creation of RESTful Web Services with sessions and persistent data
 
 =head2 VERSION
 
-version 3.010
+version 3.012
 
 =head2 SYNOPSIS
 
-Using I<curl> ( L<https://curl.haxx.se> ) as client. At your main script you can use all the Dancer2 core methods.
+Using I<curl> ( L<https://curl.haxx.se> ) as client. At your main script you can use all Dancer2 core methods.
 
 All replies have the extra keys B<error> and B<errormessage> . At success B<error> will be 0 . At fail the B<error> will be non 0 while the B<errormessage> will contain a description of the error
 
